changeset 1390:ac60cab45463

Remove FWL debris and rename do_rename to do_manifest while we're at it. (Based on prompting from Alessio Bogani).
author Rob Landley <rob@landley.net>
date Fri, 17 Jun 2011 12:42:12 -0500
parents 02ada84fcbc5
children 42ec661e3916
files download.sh sources/functions.sh
diffstat 2 files changed, 9 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/download.sh	Fri Jun 17 12:15:34 2011 +0200
+++ b/download.sh	Fri Jun 17 12:42:12 2011 -0500
@@ -115,8 +115,8 @@
 # Create a MANIFEST file listing package versions.
 
 # This can optionally call source control systems (hg and svn) to get version
-# information for the FWL build scripts and any USE_UNSTABLE packages.  These
+# information for the build scripts and any USE_UNSTABLE packages.  These
 # are intentionally excluded from the new path setup by host-tools.sh, so
 # just in case we've already run that use $OLDPATH for this.
 
-PATH="$OLDPATH" do_readme > "$SRCDIR"/MANIFEST || dienow
+PATH="$OLDPATH" do_manifest > "$SRCDIR"/MANIFEST || dienow
--- a/sources/functions.sh	Fri Jun 17 12:15:34 2011 +0200
+++ b/sources/functions.sh	Fri Jun 17 12:42:12 2011 -0500
@@ -110,7 +110,7 @@
 {
   PREVIOUS=
   (cd "$STAGE_DIR" || dienow
-   find . -depth -newer "$CURSRC/FWL-TIMESTAMP" \
+   find . -depth -newer "$CURSRC/BUILD-TIMESTAMP" \
      | sed -e 's/^.//' -e 's/^.//' -e '/^$/d'
   ) | while read i
   do
@@ -208,7 +208,7 @@
 
   if [ ! -z "$BINARY_PACKAGE_TARBALLS" ]
   then
-    touch "$CURSRC/FWL-TIMESTAMP" || dienow
+    touch "$CURSRC/BUILD-TIMESTAMP" || dienow
     TIME=$(date +%s)
     while true
     do
@@ -279,18 +279,18 @@
 
 # Create a README identifying package versions in current build.
 
-do_readme()
+do_manifest()
 {
   # Grab FWL version number
 
-  [ -z "$FWL_VERS" ] &&
-    FWL_VERS="mercurial rev $(cd "$TOP"; hg tip 2>/dev/null | sed -n 's/changeset: *\([0-9]*\).*/\1/p')"
+  [ -z "$SCRIPT_VERS" ] &&
+    SCRIPT_VERS="mercurial rev $(cd "$TOP"; hg tip 2>/dev/null | sed -n 's/changeset: *\([0-9]*\).*/\1/p')"
 
   cat << EOF
 Built on $(date +%F) from:
 
   Build script:
-    Aboriginal Linux (http://landley.net/aboriginal) $FWL_VERS
+    Aboriginal Linux (http://landley.net/aboriginal) $SCRIPT_VERS
 
   Base packages:
     uClibc (http://uclibc.org) $(identify_release uClibc)
@@ -279,18 +279,18 @@
 {
-  # Grab FWL version number
+  # Grab build script version number
 